package com.fs.company.service;

import com.fs.company.domain.CompanyWxClient;
import com.fs.company.vo.AddWxResultVo;

import java.util.List;

/**
 * 添加个微信账号Service接口
 * 
 * @author fs
 * @date 2024-12-09
 */
public interface ICompanyWxClientService 
{
    /**
     * 查询添加个微信账号
     * 
     * @param id 添加个微信账号ID
     * @return 添加个微信账号
     */
    public CompanyWxClient selectCompanyWxClientById(Long id);

    /**
     * 查询添加个微信账号列表
     * 
     * @param companyWxClient 添加个微信账号
     * @return 添加个微信账号集合
     */
    public List<CompanyWxClient> selectCompanyWxClientList(CompanyWxClient companyWxClient);
    public List<CompanyWxClient> selectCompanyWxClientListCompany(CompanyWxClient companyWxClient);

    /**
     * 新增添加个微信账号
     * 
     * @param companyWxClient 添加个微信账号
     * @return 结果
     */
    public int insertCompanyWxClient(CompanyWxClient companyWxClient);

    /**
     * 修改添加个微信账号
     * 
     * @param companyWxClient 添加个微信账号
     * @return 结果
     */
    public int updateCompanyWxClient(CompanyWxClient companyWxClient);

    /**
     * 批量删除添加个微信账号
     * 
     * @param ids 需要删除的添加个微信账号ID
     * @return 结果
     */
    public int deleteCompanyWxClientByIds(Long[] ids);

    /**
     * 删除添加个微信账号信息
     * 
     * @param id 添加个微信账号ID
     * @return 结果
     */
    public int deleteCompanyWxClientById(Long id);

    List<CompanyWxClient> toDayAddWxAccountList(Long companyId, Long accountId, Integer addType);

    void addWxResult(AddWxResultVo vo);

    void addWxTrueResult(AddWxResultVo vo);

}
